@@ -17,6 +17,8 @@
 #ifndef FMT_USE_WINDOWS_H
 #define FMT_USE_WINDOWS_H 0
 #endif
+// enable the 'n' flag in for backward compatibility with fmt 6.x
+#define FMT_DEPRECATED_N_SPECIFIER
 #include <spdlog/fmt/bundled/core.h>
 #include <spdlog/fmt/bundled/format.h>
 #else // SPDLOG_FMT_EXTERNAL is defined - use external fmtlib
